Module chat

Module chat 

Slack WEB API methods for chat.

Modules

delete
Deletes a message.
See: https://api.slack.com/methods/chat.delete
delete_scheduled_message
Deletes a pending scheduled message from the queue. See: https://api.slack.com/methods/chat.deleteScheduledMessage
get_permalink
Retrieve a permalink URL for a specific extant message.
See: https://api.slack.com/methods/chat.getPermalink
me_message
Share a me message into a channel.
See: https://api.slack.com/methods/chat.meMessage
message
Slack Message Object.
post_ephemeral
Sends an ephemeral message to a user in a channel.
See: https://api.slack.com/methods/chat.postEphemeral
post_message
Sends a message to a channel.
See: https://api.slack.com/methods/chat.postMessage
schedule_message
Schedules a message to be sent to a channel.
See: https://api.slack.com/methods/chat.scheduleMessage
scheduled_messages_list
Returns a list of scheduled messages.
See: https://api.slack.com/methods/chat.scheduledMessages.list
update
Updates a message.
See: https://api.slack.com/methods/chat.update